==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/db_backup.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	db_backup.lang.inc.php 2015-03-26 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'backup_directory' => 'Sicherungsverzeichnis',
	'backup_directory_does_not_exist' => 'Verzeichnis existiert nicht',
	'backup_directory_not_writeable' => 'Verzeichnis ist schreibgeschützt',
	'backup_in_process' => 'Sicherung wird erstellt...',
	'compressing_backup' => 'Sicherung wird komprimiert...',
	'create_backup' => 'Sicherung erstellen',
	'create_backup_hint' => 'Bitte den Sicherungsprozess AUF KEINEN FALL unterbrechen. Dieser kann einige Minuten in Anspruch nehmen.<br /><br />Hinweis: Es werden keine Artikelbilder und Shopdateien gesichert! Diese können Sie separat mit einem FTP-Programm herunterladen, um sie lokal zu sichern.',
	'date' => 'Datum',
	'delete_backup' => 'Sicherung löschen',
	'delete_db_backup_confirm' => 'Möchten Sie diese Sicherung wirklich löschen?',
	'delete_tmp_files' => 'Temporäre Dateien werden gelöscht...',
	'download_backup' => 'Sicherung herunterladen',
	'filename' => 'Dateiname',
	'headline' => 'Datenbanksicherung',
	'no_backups_created' => 'Es wurden bisher keine Datenbanksicherungen erstellt.',
	'process_completed' => 'Vorgang abgeschlossen!',
	'restoration_in_process' => 'Datenbanksicherung wird eingespielt...',
	'restore' => 'Wiederherstellen',
	'restore_backup_selection' => 'Bitte wählen Sie die Sicherungsdatei aus, die Sie wiederherstellen möchten',
	'restore_hint' => 'Den Wiederherstellungsprozess AUF KEINEN FALL unterbrechen.<br /><br />Je größer die Sicherungsdatei, desto länger dauert die Wiederherstellung!',
	'size' => 'Größe'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/db_backup.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	db_backup.lang.inc.php 2015-03-26 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'backup_directory' => 'Sicherungsverzeichnis',
	'backup_directory_does_not_exist' => 'Verzeichnis existiert nicht',
	'backup_directory_not_writeable' => 'Verzeichnis ist schreibgeschützt',
	'backup_in_process' => 'Sicherung wird erstellt...',
	'compressing_backup' => 'Sicherung wird komprimiert...',
	'create_backup' => 'Sicherung erstellen',
	'create_backup_hint' => 'Bitte den Sicherungsprozess AUF KEINEN FALL unterbrechen. Dieser kann einige Minuten in Anspruch nehmen.<br /><br />Hinweis: Es werden keine Artikelbilder und Shopdateien gesichert! Diese kannst du separat mit einem FTP-Programm herunterladen, um sie lokal zu sichern.',
	'date' => 'Datum',
	'delete_backup' => 'Sicherung löschen',
	'delete_db_backup_confirm' => 'Möchtest du diese Sicherung wirklich löschen?',
	'delete_tmp_files' => 'Temporäre Dateien werden gelöscht...',
	'download_backup' => 'Sicherung herunterladen',
	'filename' => 'Dateiname',
	'headline' => 'Datenbanksicherung',
	'no_backups_created' => 'Es wurden bisher keine Datenbanksicherungen erstellt.',
	'process_completed' => 'Vorgang abgeschlossen!',
	'restoration_in_process' => 'Datenbanksicherung wird eingespielt...',
	'restore' => 'Wiederherstellen',
	'restore_backup_selection' => 'Bitte wähle die Sicherungsdatei aus, die du wiederherstellen möchtest',
	'restore_hint' => 'Den Wiederherstellungsprozess AUF KEINEN FALL unterbrechen.<br /><br />Je größer die Sicherungsdatei, desto länger dauert die Wiederherstellung!',
	'size' => 'Größe'
);
